<?php

namespace Assetdocs\Manufacturer\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Manufacturer\Interfaces\ManufacturerRepositoryInterface;
use Assetdocs\Manufacturer\Repositories\Presenter\ManufacturerItemTransformer;

/**
 * Pubic API controller class.
 */
class ManufacturerApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Manufacturer\Interfaces\ManufacturerRepositoryInterface $manufacturer
     *
     * @return type
     */
    public function __construct(ManufacturerRepositoryInterface $manufacturer)
    {
        $this->middleware('api');

        $this->repository = $manufacturer;
        parent::__construct();
    }

    /**
     * Show manufacturer's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $manufacturers = $this->repository
            ->pushCriteria(new \Assetdocs\Manufacturer\Repositories\Criteria\ManufacturerPublicCriteria())
            ->setPresenter('\\Assetdocs\\Manufacturer\\Repositories\\Presenter\\ManufacturerListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $manufacturers['code'] = 2000;
        return response()->json($manufacturers)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show manufacturer.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $manufacturer = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($manufacturer)) {
            $manufacturer         = $this->itemPresenter($module, new ManufacturerItemTransformer);
            $manufacturer['code'] = 2001;
            return response()->json($manufacturer)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
